@@ -894,7 +894,7 @@ foceiControl <- function(sigdig = 3, #
                          gradProgressOfvTime = 10, #
                          addProp = c("combined2", "combined1"),
                          badSolveObjfAdj=100, #
-                         compress=TRUE, #
+                         compress=FALSE, #
                          rxControl=NULL,
                          sigdigTable=NULL,
                          fallbackFD=FALSE,
