@@ -71,7 +71,7 @@ n1qn1Control <- function(epsilon = (.Machine$double.eps) ^ 0.25,
                          literalFix=TRUE,
                          literalFixRes=TRUE,
                          addProp = c("combined2", "combined1"),
-                         calcTables=TRUE, compress=TRUE,
+                         calcTables=TRUE, compress=FALSE,
                          covMethod=c("r", "n1qn1", ""),
                          adjObf=TRUE, ci=0.95, sigdig=4, sigdigTable=NULL, ...) {
 
