@@ -203,7 +203,22 @@ nmObjGet.default <- function(x, ...) {
   .env <- x[[1]]
   if (exists(.arg, envir = .env)) {
     .ret <- get(.arg, envir = .env)
-    if (inherits(.ret, "raw")) .ret <- qs::qdeserialize(.ret)
+    if (inherits(.ret, "raw")) {
+      .ret <- try(qs2::qs_deserialize(.ret), silent=TRUE)
+      if (inherits(.ret, "try-error")) {
+        .ret <- try({
+          rxode2::rxReq("qs")
+          qs::qdeserialize(get(.arg, envir = .env))
+        })
+        if (inherits(.ret, "try-error")) {
+          warning("cannot deserialize object '", .arg, "'; please ensure the 'qs2' or 'qs' package is installed", call.=FALSE)
+          .ret <- NULL
+        } else {
+          # reassign the qs2 object for future use
+          assign(.arg, qs2::qs_serialize(.ret), envir = .env)
+        }
+      }
+    }
     return(.ret)
   }
   # Now get the ui, install the control object temporarily and use `rxUiGet`
