@@ -163,7 +163,7 @@ saemControl <- function(seed = 99,
                         perNoCor=0.75,
                         perFixOmega=0.1,
                         perFixResid=0.1,
-                        compress=TRUE,
+                        compress=FALSE,
                         rxControl=NULL,
                         sigdig=NULL,
                         sigdigTable=NULL,
