@@ -56,6 +56,9 @@ SEXP _nlmixr2est_freeFocei(void);
 SEXP _nlmixr2est_nlmixr2Gill83_(SEXP, SEXP, SEXP, SEXP, SEXP,
                                 SEXP, SEXP, SEXP, SEXP);
 
+SEXP _nlmixr2est_rxode2version4(SEXP);
+SEXP _nlmixr2est_rxode2stateOde(SEXP);
+
 SEXP _nlmixr2est_nlmixr2Grad_(SEXP, SEXP);
 SEXP _nlmixr2est_nlmixr2Eval_(SEXP, SEXP);
 SEXP _nlmixr2est_nlmixr2ParHist_(SEXP);
@@ -121,7 +124,14 @@ SEXP _nlmixr2est_iniN1qn1cPtrs(SEXP ptr);
 
 SEXP _nlmixr2est_iniLbfgsb3ptr(SEXP ptr);
 
+SEXP _rxode2version4(SEXP);
+SEXP _nlmixr2est_rxode2stateOde(SEXP);
+SEXP _rxode2rxFixRes(SEXP, SEXP);
+
 static const R_CallMethodDef CallEntries[] = {
+  {"_rxode2rxFixRes", (DL_FUNC) &_rxode2rxFixRes, 2},
+  {"_rxode2version4", (DL_FUNC) &_rxode2version4, 1},
+  {"_nlmixr2est_rxode2stateOde", (DL_FUNC) &_nlmixr2est_rxode2stateOde, 1},
   {"_nlmixr2est_iniLbfgsb3ptr", (DL_FUNC) &_nlmixr2est_iniLbfgsb3ptr, 1},
   {"_nlmixr2est_iniN1qn1cPtrs", (DL_FUNC) &_nlmixr2est_iniN1qn1cPtrs, 1},
   {"_nlmixr2est_iniRxodePtrs", (DL_FUNC) &_nlmixr2est_iniRxodePtrs, 1},
