@@ -24,12 +24,12 @@ nmTest({
     }
 
     ## The fit is performed by the function nlmixr/nlmix2 specifying the model, data and estimate
-    fit <- nlmixr2(one.compartment, theo_sd,  est="focei",
+    fit <-.nlmixr(one.compartment, theo_sd, est = "focei",
                    foceiControl(maxOuterIterations = 0L))
 
     md <- do.call("predict", c(list(fit, theo_md), fit$control))
 
-    md2 <- nlmixr2(fit, theo_md, "predict")
+    md2 <-.nlmixr(fit, theo_md, "predict")
 
     expect_equal(as.data.frame(md), as.data.frame(md2), tolerance = 1e-4)
 
