@@ -2,7 +2,7 @@ if (FALSE) {
 
   nmTest({
 
-    skip_if_not(file.exists(test_path("test-saem-theo_sd.qs")))
+    skip_if_not(file.exists(test_path("test-saem-theo_sd.qs2")))
 
     mod <- function() {
       ini({
@@ -184,9 +184,9 @@ if (FALSE) {
       val[, .n] <- round(val[[.n]], 2)
     }
 
-    ##qs::qsave(val, file=test_path("test-saem-theo_sd.qs"))
+    ##qs2::qs_save(val, file=test_path("test-saem-theo_sd.qs2"))
 
-    .test <- qs::qread(test_path("test-saem-theo_sd.qs"))
+    .test <- qs2::qs_read(test_path("test-saem-theo_sd.qs2"))
 
     for (i in seq_along(.test$add)) {
       test_that(
